@@ -1,14 +1,17 @@
 test_that("reptSplitCheck returns expected output", {
+  skip_on_cran()
+  skip_if_offline()
   
-  query <- c("Vieira-Alencar authoristicus",
-             "Tantilla melanocephala",
+  query <- c("Tantilla melanocephala",
              "Oxybelis aeneus",
              "Apostolepis dimidiata",
              "Bothrops pauloensis")
   
-  result <- reptSplitCheck(x=query, pubDate = 2019, cores = 2, showProgress = FALSE)
+  
+  result <- reptSplitCheck(x=query, pubDate = 2019, cores = 1, showProgress = FALSE)
   
   expect_s3_class(result, "data.frame")
   expect_true("RDB" %in% names(result))
-  expect_gt(nrow(result), 0)
-})
\ No newline at end of file
+  expect_gte(nrow(result), 0)
+  
+})
